Changelog
=========

0.0.2 (2025-03-14)
------------------

- added support for placeholders
- `from-gitingest-pt`: fixed loading URLs/dirs from text files (`-I`)


0.0.1 (2025-01-07)
------------------

- initial release

